This package has two methods as specified below.
The methods both calculate expected loss, one for single calculations and the other for full dataframes.

expectedloss_single Calculates Expected Loss for single values and takes: PD, LGD and EAD as parameters.

expectedloss_dataframe Calculates Expected Loss for a whole dataframe.
The expected parameter is a dataframe. 
For the calculation to be successfull the dataframe needs to contain "pd", "lgd" and "ead" as column names.

Please try and any feedback is very welcome for future releases!
